@@ -219,9 +219,9 @@ class FlowsSplit(Enum):
     Routes = "routes"  #:
     Buyers = "buyer"  #:
     Sellers = "seller"  #:
-    VesselTypeOil = "vessel type oil"
-    VesselTypeCpp = "vessel type cpp"
-    CrudeQuality = "crude quality"
+    VesselTypeOil = "vessel type oil"  #:
+    VesselTypeCpp = "vessel type cpp"  #:
+    CrudeQuality = "crude quality"  #:
 
 
 class FlowsPeriod(Enum):
